// File: Power.h
//------------------------------------------------------------------------------
// Author: Giovanni de Sanctis
// Email: info@lateral-technologies.com
//------------------------------------------------------------------------------
// Date: Dec 2018
// Pushbutton, onboard LEDs and other power related functions
//------------------------------------------------------------------------------



#ifndef POWER_H
#define	POWER_H

#include <stdint.h>

#define ADC_BITS            10              //ADC's number of bits 
#define VREF10              33              //Vref x 10

//Blink patterns for each function
//Power off
#define LED_RED_OFF         0x00000000
//Power ON
#define LED_RED_ON          0x00010000
//Unit switching off
#define LED_RED_ONOFF       0xAAAAAAAA
//Power ON, low battery
#define LED_RED_BATT        0xF000F000

//BT off
#define LED_BLUE_OFF        0x00000000
//BT advertising
//#define LED_BLUE_ADVERT     0xF83E07C0
#define LED_BLUE_ADVERT     0xFF00FF00
//BT connected
#define LED_BLUE_CNNCTD     0x00000003

//RF receive
#define LED_BLUE_RFRX       0x55555555

#define LED_RED_On()        IO_LED_RED_N_SetLow()
#define LED_RED_Off()       IO_LED_RED_N_SetHigh()
#define LED_BLUE_On()       IO_LED_BLUE_N_SetLow()
#define LED_BLUE_Off()      IO_LED_BLUE_N_SetHigh()


//Called after reset to hold the LDO's enable pin high
//It also initialises all the power-related variables
void powerBootstrap();

//Sets flag to shut down the system 
void shutDown();

//Manages the power button and returns 1 if pressed for >1 second
uint8_t checkPowerButton();

//Set the pattern for the LEDs (e.g. 0x00000000 off, 0x0F0F0F0F0F blink 0.4s on 0.4s off)
void setBluePattern(uint32_t pattern);

//Returns the battery voltage in fractions of 2.048V, i.e. 0x00=0V, 0xFF=2V
//the lsb indicates wheather the voltage is above a set threshold THR_BATT
//if lsb=0 then the voltage is below the threshold.
//The battery voltage depends on the voltage divider between battery and ADC in.
uint16_t getBatt();

//Returns the battery charge remaining, expressed in 'bars', from 0 to 4
uint8_t getBattBars();

//Returns 1 if battery voltage is below threshold
uint8_t isBattLow();

//Waits 20mS (for servo timing)
void wait20ms();

#endif	/* POWER_H */

